OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Искате ли да добавите отдалечено споделяне {name} от {owner}@{remote}?",
    "Remote share" : "Отдалечено споделяне",
    "Remote share password" : "Парола за отдалечено споделяне",
    "Cancel" : "Отказ",
    "Add remote share" : "Добави отдалечено споделяне",
    "Invalid Federated Cloud ID" : "Невалиден Federated Cloud ID",
    "Server to server sharing is not enabled on this server" : "Споделяне между сървъри не е разрешено на този сървър.",
    "Couldn't establish a federated share." : "Неуспешно осъществяване на федерално споделяне",
    "Couldn't establish a federated share, maybe the password was wrong." : "Неуспешно осъществяване на федерално споделяне, можеби паролата е грепна.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Заявката за Федерирано споделяне е изпратена, ще получите покана. Проверете вашите известия.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Не можа да се установи федерирано споделяне, изглежда, че сървърът за федериране е твърде стар (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Не е разрешено изпращането на федерирани групови споделяния от този сървър.",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Неуспешно споделяне на %1$s, защото този елемент вече е споделен с потребителя %2$s",
    "Not allowed to create a federated share with the same user" : "Не е позволено създаване на федерално споделяне със същият потребител",
    "Federated shares require read permissions" : "Обединените споделяния изискват права за четене",
    "File is already shared with %s" : "Файлът е вече споделен с %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Неуспешно споделяне на %1$s, не можа да се намери %2$s, може би сървърът в момента е недостъпен или използва самоподписан сертификат.",
    "Could not find share" : "Споделянето не можа да се намери",
    "Federated sharing" : "Федерално споделяне",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Получихте {share} като отдалечено споделяне от {user} (от името на {behalf})",
    "You received {share} as a remote share from {user}" : "Получихте {share}, като отдалечено споделяне от {user}",
    "Accept" : "Приемам",
    "Decline" : "Отхвърляне",
    "Federated Cloud Sharing" : "Федерирано споделяне в облак",
    "Sharing" : "Споделяне",
    "Federated file sharing" : "Федерирано споделяне на файлове",
    "Provide federated file sharing across servers" : "Осигуряване на федерирано споделяне на файлове между сървъри",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Настройка, как хората да могат да споделят между сървърите. Това включва и споделяния между потребители на този сървър, ако те използват федерирано споделяне.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Позволете на потребителите на този сървър да изпращат споделяния към други сървъри (тази опция също позволява WebDAV достъп до публични споделяния)",
    "Allow users on this server to receive shares from other servers" : "Позволи на потребители на този сървър да получават споделени папки от други сървъри",
    "Allow users on this server to send shares to groups on other servers" : "Позволете на потребителите на този сървър да изпращат споделяния до групи на други сървъри",
    "Allow users on this server to receive group shares from other servers" : "Позволете на потребители на този сървър да получават групови споделяния от други сървъри",
    "Search global and public address book for users" : "Търсене на глобална и публична адресна книга за потребители",
    "Allow users to publish their data to a global and public address book" : "Позволете на потребителите да публикуват своите данни в глобална и публична адресна книга",
    "Unable to update federated files sharing config" : "Не може да се актуализира конфигурацията за споделяне на обединени файлове",
    "Federated Cloud" : "Федериран облак",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Можете да споделяте с всеки, който използва сървър Nextcloud или други сървъри и услуги, съвместими с Open Cloud Mesh (OCM)! Просто поставете техния идентификатор за Федериран облак в диалоговия прозорец за споделяне. Изглежда като person@cloud.example.com",
    "Your Federated Cloud ID:" : "Вашият Federated Cloud ID:",
    "Share it so your friends can share files with you:" : "Споделете, за да могат приятелите ви да споделят файлове, с вас:",
    "Facebook" : "Фейсбук",
    "Twitter" : "Twitter",
    "Diaspora" : "Диаспора",
    "Add to your website" : "Добавете към вашия уеб сайт",
    "Share with me via Nextcloud" : "Споделете с мен, чрез Nextcloud",
    "HTML Code:" : "HTML код:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Споделете с мен чрез моя #Nextcloud Federated Cloud ID, вижте {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Споделете с мен, чрез моя #Nextcloud Federated Cloud ID",
    "Cloud ID copied to the clipboard" : "Cloud идентификатора е копиран в клипборда",
    "Copy to clipboard" : "Копиране в клипборда",
    "Clipboard is not available" : "Клипбордът не е достъпен",
    "Copied!" : "Копирано!",
    "Copy" : "Копиране",
    "Not supported!" : "Не се поддържа!",
    "Press ⌘-C to copy." : "За копиране натиснете ⌘-C",
    "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Получихте „%3$s“, като отдалечен дял от %4$s (%1$s) (от името на %5$s (%2$s))",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Получихте „%3$s“, като отдалечено споделяне от %4$s (%1$s)",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Споделете с мен, чрез моя #Nextcloud Federated Cloud ID - %s",
    "Open documentation" : "Отвори документацията"
},
"nplurals=2; plural=(n != 1);");
